@@ -87,14 +87,15 @@ class Point:
     _point_id: ID = None
 
     @log
-    def __init__(self, user: User, is_async: bool = False):
+    def __init__(self, user: User, is_async: bool = False, timeout: tuple = (30, 30)):
         self._user = user
         self._cache = None
         self._response = None
         self._is_async = is_async
         self._client = (Request(service=self._point_id.service,
                                 path=self._path,
-                                user=user
+                                user=user,
+                                timeout=timeout,
                                 ) if not is_async else
                         Tasks(service=self._point_id.service,
                               path=self._path,
